Enregistrement | OiRA

Thèmes

# Enregistrement

## Pourquoi dois-je m’enregistrer?

Lorsque vous commencerez votre première évaluation des risques, il vous sera demandé de créer un compte OiRA. Il s’agit d’une procédure simple et rapide.

L’enregistrement vous permet de vous connecter à tout moment pour accéder à vos données, poursuivre les évaluations précédentes ou en commencer de nouvelles.

Grâce à l’enregistrement, le système OiRA peut sauvegarder toutes vos sessions, et vos données seront toujours disponibles.

Lisez notre politique de confidentialité et découvrez comment nous traitons vos données à caractère personnel.

## Quelle est la différence entre les deux options: s’inscrire en tant qu’utilisateur et lancer une session d’essai?

La session d’essai permet aux parties intéressées de se faire une idée de l’outil avant de décider de s’inscrire ou non. Veuillez noter cependant que pendant une session d’essai, vos données ne sont pas enregistrées et que vous ne pourrez pas retrouver ultérieurement les informations que vous avez saisies. La session d’essai ne vous permet pas d’imprimer les rapports. En revanche, l’enregistrement de votre compte vous permet de documenter entièrement votre évaluation des risques.

## S’inscrire et créer un compte

C’est votre première visite? Suivez ces étapes simples pour commencer:

1.) Cliquez sur «s’inscrire» pour afficher le formulaire d’inscription.

Formulaire d'inscription.

2.) Saisissez votre adresse de courrier électronique et indiquez un mot de passe (deux fois)

3.) Cliquez sur «suivant» pour enregistrer votre nouveau compte.

4.) Lisez et acceptez la politique de confidentialité pour continuer

Vous allez être connecté au système OiRA.

## Connexion à un compte existant

Si vous êtes déjà inscrit, vous pouvez accéder à votre compte de la manière suivante:

1.) Allez sur le formulaire de connexion. Un lien vers le formulaire de connexion apparaîtra chaque fois que vous essaierez d’accéder à l’OiRA, tant que vous ne serez pas connecté.

Formulaire de connexion.

2.) Saisissez votre adresse de courrier électronique et votre mot de passe.

3.) Connectez-vous en cliquant sur le bouton «Connexion».

Une fois connecté, vous verrez l’écran ci-dessous. À partir de là, vous pouvez commencer une nouvelle évaluation des risques ou revenir aux évaluations des risques que vous avez commencées précédemment.

Le tableau de bord.

Commencez une nouvelle évaluation des risques en lui donnant un nom (par exemple, Ma-société 2018-07-03) ou accédez à l’une de vos précédentes évaluations des risques. Toutes vos évaluations de risques sont sauvegardées et peuvent être consultées ultérieurement, sauf si vous choisissez de les supprimer.

Scroll to top Load toolbar…
Back

## 1-registration.md

Help

Standard search Advanced search

- Splash and Shine Cleaners Last saved 19 days ago based on EU Cleaning More
- Commercial Guardinng, Leicester Last saved 2 months ago based on Private Security EU More
- Private Security, Grafton Street Last saved 2 months ago based on Private Security EU More
- Office operations in times of COVID-19 Last saved 4 months ago based on COVID-19 More